ReportLab Preppy Test Suite 010

# Preppy Test 010 - Preppy Variables

This test passes a dictionary to Preppy. The items in this dictionary have the same names as variables within Preppy.

This check is to see if Preppy can handle a clash between its own variable names and things that are being passed to it.

## Expected Output

You should see a long list of variable names between the two lines.

{'STARTDELIMITER': 'STARTDELIMITER', 'ENDDELIMITER': 'ENDDELIMITER', 'QSTARTDELIMITER': 'QSTARTDELIMITER', 'QENDDELIMITER': 'QENDDELIMITER', 'QUOTE': 'QUOTE', 'QUOTEQUOTE': 'QUOTEQUOTE', 'UNESCAPES': 'UNESCAPES', 'VERSION': 'VERSION', 'KEYWORDS': 'KEYWORDS', 'out': 'out', 'a': 'a', 'start': 'start', 'lines': 'lines', 'firstpass': 'firstpass', 'linemax': 'linemax', 'result': 'result', 's': 's', 'x': 'x', 'Substringquotes': 'Substringquotes', 'cursor': 'cursor', 'lineno': 'lineno', 'DIAGNOSTIC_FUNCTION': 'DIAGNOSTIC_FUNCTION', 'dictlines': 'dictlines', 'adddict': 'adddict', 'done': 'done', 'starttaglen': 'starttaglen', 'endtaglen': 'endtaglen', 'dictassntemplate': 'dictassntemplate', 'key_seen': 'key_seen', 'findpercent': 'findpercent', 'findstarttag': 'findstarttag', 'findmin': 'findmin', 'sclean': 'sclean', 'findendtag': 'findendtag', 'savecursor': 'savecursor', 'ValueError': 'ValueError', 'block': 'block', 'blockx': 'blockx', 'sblock': 'sblock', 'c': 'c', 'rc': 'rc', 'substitutionline': 'substitutionline', 'stringsub': 'stringsub', 'addpart': 'addpart', 'teststring': 'teststring', 'yislonger': 'yislonger', 'loop': 'loop', 'TOPLEVELWRAPPER': 'TOPLEVELWRAPPER', '__save_sys_stdout__': '__save_sys_stdout__', 'TOPLEVELPROLOG': 'TOPLEVELPROLOG', 'outputfile': 'outputfile', 'NameError': 'NameError', '__write__': '__write__', '__d__': '__d__', '__n__': '__n__', '__c__': '__c__', '__forbidden__': '__forbidden__', 'indentstring': 'indentstring', 'toplevel': 'toplevel', 'segment': 'segment', 'outputlist': 'outputlist', 'prints': 'prints', 'newcursor': 'newcursor', 'oldcursor': 'oldcursor', 'inputtext': 'inputtext', 'startblock': 'startblock', 'conditional': 'conditional', 'iconditional': 'iconditional', 'inif': 'inif', 'complexdirective': 'complexdirective', 'directive': 'directive', 'ddblock': 'ddblock', 'blockmode': 'blockmode', 'compilemode': 'compilemode', 'endtag': 'endtag', 'endlocation': 'endlocation', 't': 't', 'v': 'v', 'tb': 'tb', 'code': 'code', 'output': 'output', 'endblock': 'endblock', 'iout': 'iout', 'module_source_template': 'module_source_template', 'lk': 'lk', 'test': 'test', 'module_source_templateline0': 'module_source_templateline0', 'sline0': 'sline0', 'ssline0': 'ssline0', 'firstword': 'firstword', 'findfirstword': 'findfirstword', 'indent': 'indent', 'linesout': 'linesout', 'l': 'l', 'lindent': 'lindent', 'fn': 'fn', 'P': 'P', 'name': 'name', 'GLOBAL_LOADED_MODULE_DICTIONARY': 'GLOBAL_LOADED_MODULE_DICTIONARY', 'sourcetext': 'sourcetext', 'verbose': 'verbose', 'sourcefilename': 'sourcefilename', 'savefile': 'savefile', 'module': 'module', 'checksum': 'checksum', 'sourcechecksum': 'sourcechecksum', 'outfilename': 'outfilename', 'outfile': 'outfile', 'textlines': 'textlines', 'i': 'i', 'l1': 'l1', 'l2': 'l2', 'l3': 'l3', 'getModule': 'getModule'}